@@ -78,7 +78,8 @@ class CAM(object):
         if hasattr(self, "running_job_id"):
             try:
                 self._remove_by_tid("running", self.running_job_id)
-                self.p.kill()
+                os.killpg(os.getpgid(self.p.pid), signal.SIGINT)
+                #self.p.kill()
             except:
                 pass
         
